# eric7.Plugins.VcsPlugins.vcsPySvn.SvnStatusDialog

Module implementing a dialog to show the output of the svn status command process.

### Global Attributes

None

### Classes

SvnStatusDialog | Class implementing a dialog to show the output of the svn status command process.

### Functions

None

## SvnStatusDialog

Class implementing a dialog to show the output of the svn status command process.

### Derived from

QWidget, SvnDialogMixin, Ui_SvnStatusDialog

### Class Attributes

None

### Class Methods

None

### Methods

SvnStatusDialog | Constructor
__add | Private slot to handle the Add context menu entry.
__addToChangelist | Private slot to add entries to a changelist.
__breakLock | Private slot to handle the Break Lock context menu entry.
__commit | Private slot to handle the Commit context menu entry.
__commitDeselectAll | Private slot to deselect all entries from commit.
__commitSelect | Private slot to select or deselect all entries.
__commitSelectAll | Private slot to select all entries for commit.
__committed | Private slot called after the commit has finished.
__diff | Private slot to handle the Diff context menu entry.
__finish | Private slot called when the process finished or the user pressed the button.
__generateItem | Private method to generate a status item in the status list.
__getChangelistItems | Private method to retrieve all entries, that are members of a changelist.
__getCommitableItems | Private method to retrieve all entries the user wants to commit.
__getLockActionItems | Private method to retrieve all entries, that have a locked status.
__getMissingItems | Private method to retrieve all entries, that have a missing status.
__getModifiedItems | Private method to retrieve all entries, that have a modified status.
__getNonChangelistItems | Private method to retrieve all entries, that are not members of a changelist.
__getUnversionedItems | Private method to retrieve all entries, that have an unversioned status.
__lock | Private slot to handle the Lock context menu entry.
__removeFromChangelist | Private slot to remove entries from their change lists.
__resizeColumns | Private method to resize the list columns.
__resort | Private method to resort the tree.
__restoreMissing | Private slot to handle the Restore Missing context menu entry.
__revert | Private slot to handle the Revert context menu entry.
__sbsDiff | Private slot to handle the Side-by-Side Diff context menu entry.
__showContextMenu | Private slot to show the context menu of the status list.
__showError | Private slot to show an error message.
__stealLock | Private slot to handle the Break Lock context menu entry.
__unlock | Private slot to handle the Unlock context menu entry.
__updateButtons | Private method to update the VCS buttons status.
__updateCommitButton | Private method to update the Commit button status.
on_addButton_clicked | Private slot to handle the press of the Add button.
on_buttonBox_clicked | Private slot called by a button of the button box clicked.
on_commitButton_clicked | Private slot to handle the press of the Commit button.
on_diffButton_clicked | Private slot to handle the press of the Differences button.
on_refreshButton_clicked | Private slot to refresh the status display.
on_restoreButton_clicked | Private slot to handle the press of the Restore button.
on_revertButton_clicked | Private slot to handle the press of the Revert button.
on_sbsDiffButton_clicked | Private slot to handle the press of the Side-by-Side Diff button.
on_statusFilterCombo_activated | Private slot to react to the selection of a status filter.
on_statusList_itemChanged | Private slot to act upon item changes.
on_statusList_itemSelectionChanged | Private slot to act upon changes of selected items.
start | Public slot to start the svn status command.

### Static Methods

None

#### SvnStatusDialog (Constructor)

SvnStatusDialog(vcs, parent=None)

Constructor

vcs (Subversion)
  reference to the vcs object
parent (QWidget)
  parent widget

#### SvnStatusDialog.__add

__add()

Private slot to handle the Add context menu entry.

#### SvnStatusDialog.__addToChangelist

__addToChangelist()

Private slot to add entries to a changelist.

#### SvnStatusDialog.__breakLock

__breakLock()

Private slot to handle the Break Lock context menu entry.

#### SvnStatusDialog.__commit

__commit()

Private slot to handle the Commit context menu entry.

#### SvnStatusDialog.__commitDeselectAll

__commitDeselectAll()

Private slot to deselect all entries from commit.

#### SvnStatusDialog.__commitSelect

__commitSelect(selected)

Private slot to select or deselect all entries.

selected (bool)
  commit selection state to be set

#### SvnStatusDialog.__commitSelectAll

__commitSelectAll()

Private slot to select all entries for commit.

#### SvnStatusDialog.__committed

__committed()

Private slot called after the commit has finished.

#### SvnStatusDialog.__diff

__diff()

Private slot to handle the Diff context menu entry.

#### SvnStatusDialog.__finish

__finish()

Private slot called when the process finished or the user pressed the button.

#### SvnStatusDialog.__generateItem

__generateItem(changelist, status, propStatus, locked, history, switched, lockinfo, uptodate, revision, change, author, path, )

Private method to generate a status item in the status list.

changelist (str)
  name of the changelist
status (pysvn.wc_status_kind)
  text status
propStatus (pysvn.wc_status_kind)
  property status
locked (bool)
  locked flag
history (bool)
  history flag
switched (bool)
  switched flag
lockinfo (str)
  lock indicator
uptodate (bool)
  up to date flag
revision (int)
  revision
change (int)
  revision of last change
author (str)
  author of the last change
path (str)
  path of the file or directory

#### SvnStatusDialog.__getChangelistItems

__getChangelistItems()

Private method to retrieve all entries, that are members of a changelist.

Return:
  list of all items belonging to a changelist

Return Type:
  list of QTreeWidgetItem

#### SvnStatusDialog.__getCommitableItems

__getCommitableItems()

Private method to retrieve all entries the user wants to commit.

Return:
  list of all items, the user has checked

Return Type:
  list of QTreeWidgetItem

#### SvnStatusDialog.__getLockActionItems

__getLockActionItems(indicators)

Private method to retrieve all entries, that have a locked status.

indicators (list of str)
  list of indicators to check against

Return:
  list of all items with a locked status

Return Type:
  list of QTreeWidgetItem

#### SvnStatusDialog.__getMissingItems

__getMissingItems()

Private method to retrieve all entries, that have a missing status.

Return:
  list of all items with a missing status

Return Type:
  list of QTreeWidgetItem

#### SvnStatusDialog.__getModifiedItems

__getModifiedItems()

Private method to retrieve all entries, that have a modified status.

Return:
  list of all items with a modified status

Return Type:
  list of QTreeWidgetItem

#### SvnStatusDialog.__getNonChangelistItems

__getNonChangelistItems()

Private method to retrieve all entries, that are not members of a changelist.

Return:
  list of all items not belonging to a changelist

Return Type:
  list of QTreeWidgetItem

#### SvnStatusDialog.__getUnversionedItems

__getUnversionedItems()

Private method to retrieve all entries, that have an unversioned status.

Return:
  list of all items with an unversioned status

Return Type:
  list of QTreeWidgetItem

#### SvnStatusDialog.__lock

__lock()

Private slot to handle the Lock context menu entry.

#### SvnStatusDialog.__removeFromChangelist

__removeFromChangelist()

Private slot to remove entries from their change lists.

#### SvnStatusDialog.__resizeColumns

__resizeColumns()

Private method to resize the list columns.

#### SvnStatusDialog.__resort

__resort()

Private method to resort the tree.

#### SvnStatusDialog.__restoreMissing

__restoreMissing()

Private slot to handle the Restore Missing context menu entry.

#### SvnStatusDialog.__revert

__revert()

Private slot to handle the Revert context menu entry.

#### SvnStatusDialog.__sbsDiff

__sbsDiff()

Private slot to handle the Side-by-Side Diff context menu entry.

#### SvnStatusDialog.__showContextMenu

__showContextMenu(coord)

Private slot to show the context menu of the status list.

coord (QPoint)
  the position of the mouse pointer

#### SvnStatusDialog.__showError

__showError(msg)

Private slot to show an error message.

msg (str)
  error message to show

#### SvnStatusDialog.__stealLock

__stealLock()

Private slot to handle the Break Lock context menu entry.

#### SvnStatusDialog.__unlock

__unlock()

Private slot to handle the Unlock context menu entry.

#### SvnStatusDialog.__updateButtons

__updateButtons()

Private method to update the VCS buttons status.

#### SvnStatusDialog.__updateCommitButton

__updateCommitButton()

Private method to update the Commit button status.

#### SvnStatusDialog.on_addButton_clicked

on_addButton_clicked()

Private slot to handle the press of the Add button.

#### SvnStatusDialog.on_buttonBox_clicked

on_buttonBox_clicked(button)

Private slot called by a button of the button box clicked.

button (QAbstractButton)
  button that was clicked

#### SvnStatusDialog.on_commitButton_clicked

on_commitButton_clicked()

Private slot to handle the press of the Commit button.

#### SvnStatusDialog.on_diffButton_clicked

on_diffButton_clicked()

Private slot to handle the press of the Differences button.

#### SvnStatusDialog.on_refreshButton_clicked

on_refreshButton_clicked()

Private slot to refresh the status display.

#### SvnStatusDialog.on_restoreButton_clicked

on_restoreButton_clicked()

Private slot to handle the press of the Restore button.

#### SvnStatusDialog.on_revertButton_clicked

on_revertButton_clicked()

Private slot to handle the press of the Revert button.

#### SvnStatusDialog.on_sbsDiffButton_clicked

on_sbsDiffButton_clicked()

Private slot to handle the press of the Side-by-Side Diff button.

#### SvnStatusDialog.on_statusFilterCombo_activated

on_statusFilterCombo_activated(index)

Private slot to react to the selection of a status filter.

index (int)
  index of the selected entry

#### SvnStatusDialog.on_statusList_itemChanged

on_statusList_itemChanged(_item, column)

Private slot to act upon item changes.

_item (QTreeWidgetItem)
  reference to the changed item (unused)
column (int)
  index of column that changed

#### SvnStatusDialog.on_statusList_itemSelectionChanged

on_statusList_itemSelectionChanged()

Private slot to act upon changes of selected items.

#### SvnStatusDialog.start

start(fn)

Public slot to start the svn status command.

fn (str or list of str)
  filename(s)/directoryname(s) to show the status of

Up